::: laktory.models.resources.databricks.MwsPermissionAssignment

---

::: laktory.models.resources.databricks.mwsnetworkconnectivityconfig.MwsNetworkConnectivityConfigEgressConfigDefaultRulesAwsStableIpRule

---

::: laktory.models.resources.databricks.mwsnetworkconnectivityconfig.MwsNetworkConnectivityConfigEgressConfigDefaultRulesAzureServiceEndpointRule

---

::: laktory.models.resources.databricks.mwsnetworkconnectivityconfig.MwsNetworkConnectivityConfigEgressConfigDefaultRules

---

::: laktory.models.resources.databricks.mwsnetworkconnectivityconfig.MwsNetworkConnectivityConfigEgressConfigTargetRulesAzurePrivateEndpointRule

---

::: laktory.models.resources.databricks.mwsnetworkconnectivityconfig.MwsNetworkConnectivityConfigEgressConfigTargetRules

---

::: laktory.models.resources.databricks.mwsnetworkconnectivityconfig.MwsNetworkConnectivityConfigEgressConfig

